PageSourceSearch

https://toppfotball.no/ak25

html toppfotball.no collected 2026-10-02 12:30:41 UTC 63,877 bytes, 1,073 lines download raw bytes

1<!DOCTYPE html>
2<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="nb" lang="nb" prefix="og:https://ogp.me/ns">
3<head>
3<script id="Cookiebot" src="https://consent.cookiebot.com/uc.js" data-cbid="6ec37fe1-0bdc-4bd0-9faf-c539a2f10ab0" data-blockingmode="auto" type="text/javascript"></script>
3<link rel="preconnect" href="https://cdn.usefathom.com">
4    <meta charset="utf-8" />
5    <meta name="viewport" content="width=device-width, initial-scale=1.0">
6    
7    <meta http-equiv="content-language" content="nb-no">
8
9    <title>Akademiklassifiseringen 2025 / Norsk Toppfotball</title>
10    <link rel="home" href="https://toppfotball.no/" />
11    <!-- Gotham XNarrow -->
12
13    <link rel="stylesheet" type="text/css" href="https://cloud.typography.com/6417356/6804032/css/fonts.css" />
14    <link rel="manifest" href="/manifest.json">
15
16    <!--<link rel="stylesheet" type="text/css" href="/css/.css"/>-->
17    <link rel="stylesheet" type="text/css" href="/_/asset/no.seeds.app.football:0000019ff1917e80/compiled/css/ntf.css"/>
18    <link rel="stylesheet" type="text/css" href="/_/service/no.seeds.app.football/asset/0000019ff1917e80/compiled/css/seeds.css"/>
19    <link rel="stylesheet" type="text/css" href="/_/service/no.seeds.app.football/asset/0000019ff1917e80/css/jquery-ui.css"/>
20    
20<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/js/jquery.js"></script>
20
21    
21<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/js/jquery-ui.js"></script>
21
22    
22<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/js/jquery.cookie.js"></script>
22
23
24    
24<script src="https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.29.1/moment.min.js" integrity="sha512-qTXRIMyZIFb8iQcfjXWCO8+M5Tbc38Qi5WzdPOYZHIlZpzBHG3L3by84BBBOiRGiEb7KKtAOAs5qYdUiZiQNNQ==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
24
25    
25<script src="https://cdnjs.cloudflare.com/ajax/libs/moment-timezone/0.5.33/moment-timezone-with-data.min.js" integrity="sha512-rjmacQUGnwQ4OAAt3MoAmWDQIuswESNZwYcKC8nmdCIxAVkRC/Lk2ta2CWGgCZyS+FfBWPgaO01LvgwU/BX50Q==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
25
26
27    
27<script async src="https://securepubads.g.doubleclick.net/tag/js/gpt.js"></script>
27
28
29    
29<script type="text/javascript">
30        var redirectSession = sessionStorage.getItem('redirectSession');
31        var urlParams = new URLSearchParams(window.location.search);
32
33        if (redirectSession) {
34            sessionStorage.removeItem('redirectSession');
35            window.location.href = redirectSession;
36        }
37    </script>
37
38    <!-- ------------ smartApp Banner ------------------------------------- -->
39    
40    <!-- ------------------------------------------------------------------ -->
41
42	
42<script src="https://static.rek.ai/0772f315.js" defer></script>
42
43
44<style>
45#CybotCookiebotDialog a,
46#CybotCookiebotDialog a:hover,
47#CybotCookiebotDialog a:after
48{	
49  background-color: transparent;
50  border-bottom: none !important;
51}
52
53#CybotCookiebotDialog img{
54	width: auto !important;
55}
56</style><style>
57                        .navigationBar__items--item > .active > svg > path {
58                            stroke: #FFDE00;
59                        }
60                    </style><link href="https://toppfotball.no/ak25" rel="canonical" />
61	
62	<meta name="description" content="Norsk Toppfotball er ligaforeningen til de 32 klubbene i Eliteserien og OBOS-ligaen." />
63	<meta property="og:title" content="Akademiklassifiseringen 2025" />
64	<meta property="og:description" content="Norsk Toppfotball er ligaforeningen til de 32 klubbene i Eliteserien og OBOS-ligaen." />
65	<meta property="og:site_name" content="Norsk Toppfotball" />
66	<meta property="og:url" content="https://toppfotball.no/ak25" />
67	<meta property="og:type" content="article" />
68	<meta property="og:locale" content="nb_NO" />
69
70	
71		<meta property="og:image" content="https://toppfotball.no/ak25/_/image/0bc46747-893a-41b8-b0c5-a218e9024cd6:1e564b18e6d98ef894f296f9fb5ff43e3baeb5c5/block-1200-630/ak%20-%20toppbilde.png.jpg?quality=85" />
72		<meta property="og:image:width" content="1200" />
73		<meta property="og:image:height" content="630" />
74	
75	
76
77
78	<link rel="apple-touch-icon" sizes="57x57" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-57x57.png">
79	<link rel="apple-touch-icon" sizes="60x60" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-60x60.png">
80	<link rel="apple-touch-icon" sizes="72x72" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-72x72.png">
81	<link rel="apple-touch-icon" sizes="76x76" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-76x76.png">
82	<link rel="apple-touch-icon" sizes="114x114" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-114x114.png">
83	<link rel="apple-touch-icon" sizes="120x120" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-120x120.png">
84	<link rel="apple-touch-icon" sizes="144x144" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-144x144.png">
85	<link rel="apple-touch-icon" sizes="152x152" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-152x152.png">
86	<link rel="apple-touch-icon" sizes="180x180" href="/_/asset/no.seeds.app.football/img/logo/ntf/apple-icon-180x180.png">
87	<link rel="icon" type="image/png" sizes="192x192"  href="/_/asset/no.seeds.app.football/img/logo/ntf/android-icon-192x192.png">
88	<link rel="icon" type="image/png" sizes="32x32" href="/_/asset/no.seeds.app.football/img/logo/ntf/favicon-32x32.png">
89	<link rel="icon" type="image/png" sizes="96x96" href="/_/asset/no.seeds.app.football/img/logo/ntf/favicon-96x96.png">
90	<link rel="icon" type="image/png" sizes="16x16" href="/_/asset/no.seeds.app.football/img/logo/ntf/favicon-16x16.png">
91
92
93
94    <meta name="apple-mobile-web-app-status-bar-style" content="#ffffff">
95    <meta name="apple-mobile-web-app-title" content="Norsk Toppfotball">
96    <meta name="apple-mobile-web-app-capable" content="yes">
97
98	<link rel="apple-touch-startup-image" href="/ak25/_/image/7d26a438-a86f-499d-8682-ec420d93c016:8d99649018fffa6e06a327526816387e32c322a6/-1-1/apple-icon-640x1136" media="(device-width: 320px) and (device-height: 568px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/e1cce8d5-f061-4055-b547-35e55c5825a2:18ea2d8156e5a802e9fb6c589ae1b25acb51fd66/-1-1/apple-icon-1136x640" media="(device-width: 320px) and (device-height: 568px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/1c686ddd-e674-4f4e-bdad-f2f83af15360:6f2524245af2075a290fae0f52f5379a7ead83f2/-1-1/apple-icon-750x1334" media="(device-width: 375px) and (device-height: 667px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/0f05c528-b773-4b4b-933e-7129e1cb6823:a5ad87eeb69ea131346897d8900a9ccce06e6e34/-1-1/apple-icon-1334x750" media="(device-width: 375px) and (device-height: 667px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/8b8d85d9-92fc-4258-a842-a2c0870cea71:92ee000b209e825d34cdbad52f29b466ea015c19/-1-1/apple-icon-1242x2208" media="(device-width: 621px) and (device-height: 1104px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/91b07258-a659-4603-be9e-9428738b924e:9a82f0807bc63b7fe91c7029817738849407dd24/-1-1/apple-icon-2208x1242" media="(device-width: 621px) and (device-height: 1104px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/17ccdead-bfd6-4
98105-ad65-c736bd7f2ec9:fe61a682255513c61e2b3777a7a0e51aa7098588/-1-1/apple-icon-1125x2436" media="(device-width: 375px) and (device-height: 812px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/60d7d902-9e16-41c5-9d2c-13520e175b04:1c50a61223706a6c34aa3465cf1b9fe4778c3286/-1-1/apple-icon-2436x1125" media="(device-width: 375px) and (device-height: 812px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/dd47173a-74e2-4881-a0ab-665156368320:8a464beb586410c11514ffd806ac5dbd07c5f093/-1-1/apple-icon-828x1792" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/f8ccf912-1c62-4735-8ecf-dbaa8c29a115:b15c6398df86e09a8f08b41e692e0acaf956e614/-1-1/apple-icon-1792x828" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/5b5921ae-3787-44cf-9e1c-6f3be7ca837b:9d8e867153e9b45d44bec6f794a007827e39a0b3/-1-1/apple-icon-1242x2688" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/3a45a2e2-9012-4915-b8ce-e3083d1b7fb1:aa4061b6fb761158eac2335b9f4d976a9077dec2/-1-1/apple-icon-2688x1242" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/641925b1-d177-4347-9c9e-643655c54116:719a80d3b50e1fed8100200f45b9082506122d28/-1-1/apple-icon-1536x2048" media="(device-width: 768px) and (device-height: 1024px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/58fe8e13-d547-4390-89bc-1d8cd7f5b250:b3a89daf9e0ad84b6a7c6429889fdf9affd80d50/-1-1/apple-icon-2048x1536" media="(device-width: 768px) and (device-height: 1024px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/064f68cc-bd8e-48fd-a7d1-c713cee3d931:804359294c8622de1f65ad439f2b38ef34a576f1/-1-1/apple-icon-1668x2224" media="(device-width: 834px) and (device-height: 1112px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/c89eedf6-59fd-4cc1-9455-b736801d9cb6:4f311a819aa1a5e74024d0c282d13bee65d10aad/-1-1/apple-icon-2224x1668" media="(device-width: 834px) and (device-height: 1112px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/e37e9308-7e5f-443c-94ab-c3f5c7d08497:f714ef2f15c80665b6af2fc185941011c6bf0e16/-1-1/apple-icon-1668x2388" media="(device-width: 834px) and (device-height: 1194px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/977b0e29-2dbd-4c25-b870-19624b6dd4df:70b749f1834c4c8538e694810f36eb306417efc6/-1-1/apple-icon-2388x1668" media="(device-width: 834px) and (device-height: 1194px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/ak25/_/image/cc999a8e-13c7-40c6-852c-5eb850eea75d:1d5f9bce255e6ade395b1a07e5efaafb4679b616/-1-1/apple-icon-2048x2732" media="(device-width: 1024px) and (device-height: 1366px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/ak25/_/image/fbd49c7c-ae34-44eb-b941-6618dcf89f50:0033e020c9339ac95903be653118cae4afefcf01/-1-1/apple-icon-2732x2048" media="(device-width: 1024px) and (device-height: 1366px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)">
99
100	<meta name="msapplication-TileColor" content="#ffffff">
101	<meta name="msapplication-TileImage" content="/_/asset/no.seeds.app.football/img/logo/ntf/ms-icon-144x144.png">
102	<meta name="theme-color" content="#ffffff">
102<script src="https://cdn.usefathom.com/script.js" data-site="KWECIDBD"  defer></script>
102</head>
103
104<body data-ng-controller="body" data-ng-class="{'menu-is-visible': showMenu}" class="body__ntf">
105
106<div class="splash--pwa" style="background-color: #ffffff">
107    <img class="fade--in--splash" src="/ak25/_/image/52cb801d-a9fd-4a7d-8a38-407d53853a7d:6f366c15b21798338edf9273223bc8dd75b9fea0/-1-1/Fantasy-1024x1024-GIF-til-Fantasy.gif">
108</div>
109<script>
110    const splashPwa = $('.splash--pwa');
111    const isRunningStandalone = (window.matchMedia('(display-mode: standalone)').matches);
112
113    const shouldShowFakeSplash = sessionStorage.getItem('splash_pwa') !== 'displayed' && isRunningStandalone;
114
115    if (shouldShowFakeSplash){
116        splashPwa.show();
117        $('.splash--pwa img').load(function () {
118            $('.splash--pwa img').show();
119        });
120    }
121
122    document.addEventListener('DOMContentLoaded', onDomLoaded);
123
124    function onDomLoaded(){
125        if (shouldShowFakeSplash){
126            setTimeout(function(){
127                splashPwa.addClass('splash--display--none');
128                sessionStorage.setItem('splash_pwa', 'displayed');
129            }, 3000);
130        }
131    };
132</script>
132
133
134
135<svg style="display:none">
136    <symbol id="arrow" viewBox="0 0 46 33">
137        <polygon points="0 18.355 41.662 18.355 41.662 14.355 0 14.355"></polygon>
138        <polygon points="28.408 32.715 25.68 29.785 40.127 16.359 25.68 2.93 28.408 0 46 16.359"></polygon>
139    </symbol>
140
141    <symbol id="arrow-right" viewBox="0 0 24 24">
142        <polygon points="7.875,0 4.125,3.75 12.375,12 4.125,20.25 7.875,24 19.875,12 "></polygon>
143    </symbol>
144
145    <symbol id="arrow-left" viewBox="0 0 24 24">
146        <polygon points="16.125,24 19.875,20.25 11.625,12 19.875,3.75 16.125,0 4.125,12 "></polygon>
147    </symbol>
148</svg>
149
150<div class="bg-overflow"></div>
151
152
153    
154        <header class="header" ng-class="{'header--show-menu': showMenu, 'header--show-search': showSearch}">
155	
156	<div class="header__global">
157		<div class="container">
158			<nav class="header__global__nav" aria-label="Meny">
159				<a class="header__global__nav__item" href="https://toppfotball.no/tjenestekatalogen">
160					Tjenestekatalogen
161				</a><a class="header__global__nav__item" href="https://toppfotball.no/manualer">
162					Manualer
163				</a>
164				<!-- Login/Logout/Minside links -->
165				<input id="idrettens-link-service" type="hidden" value="https://toppfotball.no/ak25/_/service/no.seeds.app.football/get-login-links">
166				<a id="login-link" class="modal__login modal-open" href="javascript:void(0)" hidden>
167                    <svg stroke="white" width="24" height="20" viewBox="0 0 24 20" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="loginTitle">
168                        <title id="loginTitle"></title>
169                        <path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke-width="1.5" stroke-miterlimit="10"/>
170                        <path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
171                    </svg>
172                </a>
173                <a id="minside-link" href="javascript:void(0)" hidden>
174                    <svg stroke="white" width="24" height="20" viewBox="0 0 24 20" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="minsideTitle">
175                        <title id="minsideTitle"></title>
176                        <path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke-width="1.5" stroke-miterlimit="10"/>
177                        <path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
178                    </svg>
179                </a>
180                <a id="logout-link" class="logout" href="javascript:void(0)" hidden>
181                    <svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
182 viewBox="0 0 384.971 384.971" style="enable-background:new 0 0 384.971 384.971;" xml:space="preserve" aria-labelledby="logoutTitle">
183                        <title id="logoutTitle"></title>
184                        <g>
185                            <g id="Sign_Out">
186                                <path d="M180.455,360.91H24.061V24.061h156.394c6.641,0,12.03-5.39,12.03-12.03s-5.39-12.03-12.03-12.03H12.03
187                                    C5.39,0.001,0,5.39,0,12.031V372.94c0,6.641,5.39,12.03,12.03,12.03h168.424c6.641,0,12.03-5.39,12.03-12.03
188                                    C192.485,366.299,187.095,360.91,180.455,360.91z"/>
189                                <path d="M381.481,184.088l-83.009-84.2c-4.704-4.752-12.319-4.74-17.011,0c-4.704,4.74-4.704,12.439,0,17.179l62.558,63.46H96.279
190                                    c-6.641,0-12.03,5.438-12.03,12.151c0,6.713,5.39,12.151,12.03,12.151h247.74l-62.558,63.46c-4.704,4.752-4.704,12.439,0,17.179
191                                    c4.704,4.752,12.319,4.752,17.011,0l82.997-84.2C386.113,196.588,386.161,188.756,381.481,184.088z"/>
192                            </g>
193                        </g>
194                    </svg>
195                </a>
196				<a class="open-push-notification-modal header__global__nav__item" href="javascript:void(0)" style="display: none;">
197                    <svg stroke="white" width="24px" height="20px" viewBox="0 0 611.999 611.999" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
198                        <title id="renewPushTitle"></title>
199                        <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
200                            C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
201                            c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
202                            h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
203                            c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
204                            C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
205                            c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
206                            c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
207                            M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
208                            c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
209                            c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"/>
210                        <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
211                            c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
212                            C323.259,126.96,315.532,119.235,306.001,119.235z"/>
213                    </svg>
214                </a>
215			</nav>
216		</div>
217	</div>
218	<div class="header__team">
219		<div class="container">
220			<a href="https://toppfotball.no/" class="header__team__brand">
221				<div class="header__team__brand__container">
222					<div class="header__team__brand__div">
223						<img class="header__team__brand__img header__team__brand__img--ntf" src="https://toppfotball.no/ak25/_/image/81feb359-1446-47e1-a9a0-136ea399a33e:96d4bfee1d4878832977533041bb1cef20edd275/wide-72-72/ntf-logo-sidetekst.svg" role="img" alt="Forsiden på toppfotball.no"/>
224					</div>
225					<div class="header__team__brand__titles">
226						
227						
228					</div>
229				</div>
230			</a>
231		</div>
232	</div>
233	<div class="header__bar">
234		<div class="container">
235			<a class="header__bar__brand" href="https://toppfotball.no/">
236				<img class="header__bar__brand__img" src="https://toppfotball.no/ak25/_/image/81feb359-1446-47e1-a9a0-136ea399a33e:96d4bfee1d4878832977533041bb1cef20edd275/wide-72-72/ntf-logo-sidetekst.svg" title="Til forsiden på https://toppfotball.no/" alt="Logo" />
237			</a>
238
239			<div class="header__menu">
240				<nav class="header__menu__nav" aria-label="Hovedmeny">
241					<!-- Set modifier class "header__menu__nav__item--active" on active menu elements -->
242					
243						
244							<a class="header__menu__nav__item" href="https://toppfotball.no/nyheter">
245								<span class="header__menu__nav__item__title">Nyheter</span>
246							</a>
247						
248					
249					
250						
251							<a class="header__menu__nav__item header__menu__nav__item--active" href="https://toppfotball.no/ak25">
252								<span class="header__menu__nav__item__title">Akademiklassifiseringen</span>
253							</a>
254						
255					
256					
257						
258							<a class="header__menu__nav__item" href="https://toppfotball.no/sport">
259								<span class="header__menu__nav__item__title">Sport</span>
260							</a>
261						
262					
263					
264						
265							<a class="header__menu__nav__item" href="https://toppfotball.no/eliteserien">
266								<span class="header__menu__nav__item__title">Eliteserien</span>
267							</a>
268						
269					
270					
271						
272							<a class="header__menu__nav__item" href="https://toppfotball.no/obos-ligaen">
273								<span class="header__menu__nav__item__title">OBOS-ligaen</span>
274							</a>
275						
276					
277					
278						
279							<a class="header__menu__nav__item" href="https://toppfotball.no/partnere">
280								<span class="header__menu__nav__item__title">Partnere</span>
281							</a>
282						
283					
284					
285						
286							<a class="header__menu__nav__item" href="https://toppfotball.no/om-oss">
287								<span class="header__menu__nav__item__title">Om oss</span>
288							</a>
289						
290					
291					
292						
293							<a class="header__menu__nav__item" href="https://toppfotball.no/sport/nasjonale-serier-ntf-elitetiltak">
294								<span class="header__menu__nav__item__title">Nasjonale serier</span>
295							</a>
296						
297					
298					
299				</nav>
300				<div class="header__menu__sponsor">
301					
302
303				</div>
304			</div>
305
306			<div class="header__bar__nav">
307				<button class="header__bar__nav__item header__bar__nav__item--menu" type="button" ng-click="toggleMenu(); showSearch = false;">
308					<span data-ng-if="!showMenu">
309						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
310<path d="M22.4511719,6H1.5C0.671875,6,0,5.3286133,0,4.5S0.671875,3,1.5,3h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
311	S23.2792969,6,22.4511719,6z"></path>
312<path d="M22.4511719,13.5H1.5C0.671875,13.5,0,12.8286133,0,12s0.671875-1.5,1.5-1.5h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
313	S23.2792969,13.5,22.4511719,13.5z"></path>
314<path d="M22.4511719,21H1.5C0.671875,21,0,20.3286133,0,19.5S0.671875,18,1.5,18h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
315	S23.2792969,21,22.4511719,21z"></path>
316</svg></span>
317						Meny
318					</span>
319					<span data-ng-if="showMenu" class="ng-cloak">
320						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
321<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
322	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
323	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
324	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
325	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
326	"></path>
327</svg></span>
328						Lukk meny
329					</span>
330				</button>
331				<button class="header__bar__nav__item header__bar__nav__item--search" type="button" ng-click="toggleSearch(); queryReset = true; showMenu = false;">
332					<span data-ng-if="!showSearch">
333						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
334<path id="search" d="M17.7191334,15.5738506c2.5573559-3.8850498,2.4550629-9.4922314-0.961565-12.9057446
335	c-4.037859-3.754458-10.3484344-3.5178807-14.095067,0.5284102c-3.5613694,3.8462107-3.5484405,9.7972965,0.0296073,13.6279316
336	c3.4166281,3.4135132,8.9916639,3.4852676,12.858386,0.9020691L21.8313618,24L24,21.8268318L17.7191334,15.5738506z
337	 M4.3185873,15.2048225C1.3234186,12.2014732,1.324975,7.3336434,4.3220639,4.3322186s7.854773-2.9998651,10.8499432,0.0034833
338	c2.9938126,3.0019879,2.9938126,7.8671322,0,10.8691206c-2.9951696,3.0033493-7.8528538,3.0049095-10.8499432,0.0034838
339	C4.3209047,15.2071447,4.319746,15.2059841,4.3185873,15.2048225z"></path>
340</svg></span>
341						Søk
342					</span>
343					<span data-ng-if="showSearch" class="ng-cloak">
344						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
345<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
346	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
347	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
348	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
349	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
350	"></path>
351</svg></span>
352						Lukk søk
353					</span>
354				</button>
355			</div>
356		</div>
357		<div class="header__search">
358			<div class="container">
359				<div class="search-field__area o-no-margin">
360					<form action="https://toppfotball.no/sok" method="get">
361
362						<input id="search-field__input_header" class="search-field__input" aria-label="Søk" type="text" autocomplete="off" data-ng-model="query"
363						    name="text" data-bind-focus="queryReset" data-ng-focus="queryReset == true" data-e
363sc-key="query = ''" placeholder="Søk i toppfotball.no" maxlength="128">
364						
365						<span class="search-field__area__icon" data-ng-show="query.length > 0" data-ng-click="query = ''; queryReset = true;">
366							<span><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
367<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
368	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
369	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
370	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
371	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
372	"></path>
373</svg></span>
374						</span>
375						<span class="search-field__area__icon" data-ng-hide="query.length > 0">
376							<span><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
377<path id="search" d="M17.7191334,15.5738506c2.5573559-3.8850498,2.4550629-9.4922314-0.961565-12.9057446
378	c-4.037859-3.754458-10.3484344-3.5178807-14.095067,0.5284102c-3.5613694,3.8462107-3.5484405,9.7972965,0.0296073,13.6279316
379	c3.4166281,3.4135132,8.9916639,3.4852676,12.858386,0.9020691L21.8313618,24L24,21.8268318L17.7191334,15.5738506z
380	 M4.3185873,15.2048225C1.3234186,12.2014732,1.324975,7.3336434,4.3220639,4.3322186s7.854773-2.9998651,10.8499432,0.0034833
381	c2.9938126,3.0019879,2.9938126,7.8671322,0,10.8691206c-2.9951696,3.0033493-7.8528538,3.0049095-10.8499432,0.0034838
382	C4.3209047,15.2071447,4.319746,15.2059841,4.3185873,15.2048225z"></path>
383</svg></span>
384						</span>
385					</form>
386				</div>
387			</div>
388		</div>
389	</div>
390</header>
391
392    
393    
394
395
396<main class="body  o-no-padding-top o-no-padding-bottom" data-portal-region="main">
397    
398    
399        
400            <style data-portal-component-type="layout">
401	main.body{
402		padding-top: 0 !important;
403	}
404</style>
405<article class="landing-page">
406    <header>
407        <div class="hero hero--background-tint hero--landing-page">
408            <div class="no__pattern">
409                
410                
411                    <picture>
412                        <source media="(max-width:500px)" srcset="/ak25/_/image/0bc46747-893a-41b8-b0c5-a218e9024cd6:1e564b18e6d98ef894f296f9fb5ff43e3baeb5c5/wide-500-281/ak%20-%20toppbilde.png.jpg 1x, /ak25/_/image/0bc46747-893a-41b8-b0c5-a218e9024cd6:1e564b18e6d98ef894f296f9fb5ff43e3baeb5c5/wide-1000-562/ak%20-%20toppbilde.png.jpg 2x">
413                        <source media="(max-width:840px)" srcset="/ak25/_/image/0bc46747-893a-41b8-b0c5-a218e9024cd6:1e564b18e6d98ef894f296f9fb5ff43e3baeb5c5/wide-840-472/ak%20-%20toppbilde.png.jpg 1x, /ak25/_/image/0bc46747-893a-41b8-b0c5-a218e9024cd6:1e564b18e6d98ef894f296f9fb5ff43e3baeb5c5/wide-1680-944/ak%20-%20toppbilde.png.jpg 2x">
414                        <img src="/ak25/_/image/0bc46747-893a-41b8-b0c5-a218e9024cd6:1e564b18e6d98ef894f296f9fb5ff43e3baeb5c5/wide-1600-900/ak%20-%20toppbilde.png.jpg">
415                    </picture>
416                
417            </div>
418
419            <div class="hero__content">
420                <div class="grid grid--justify-center">
421
422                    
423
424
425                    
426
427                    
428
429
430
431                </div>
432            </div>
433        </div>
434    </header>
435</article>
436
437
438
439            
440        
441        
442            <div data-portal-component-type="part" class="container">
443   <!--------------- Alternating view --------------->
444   <div class="content-blocks">
445      
446      <div class="content-blocks__wrapper">
447
448         
449
450            <div class="item rounded">
451               <div class="item__wrapper">
452                  <figure class="item__image">
453                     <img alt="Image" src="https://toppfotball.no/ak25/_/image/ea7fa392-762a-4e69-bd25-45fcfd994738:3c4baf79128654b63563f46353d81b0a54640450/block-800-450/AK_Forsidebilder_Forord.png.jpg">
454                  </figure>
455                  <div class="item__content">
456                     <div class="item__title">
457                        <h2>
458                           <span>Forord</span>
459                        </h2>
460                     </div>
461                     <div class="item__text">
462                        <span>Les Jens Haugland, Erik Hoftun og Karl-Petter Løkens tanker rundt årets rapport.</span>
463                     </div>
464                     <div class="item__icon">
465                        <svg xmlns="http://www.w3.org/2000/svg" width="46" height="32.715" viewBox="0 0 46 32.715">
466                           <title>arrow</title>
467                           <g>
468                              <line y1="16.355" x2="41.662" y2="16.355" style="fill: none;stroke: var(--icon-color);stroke-miterlimit: 10;stroke-width: 4px" />
469                              <polygon points="28.408 32.715 25.68 29.785 40.127 16.359 25.68 2.93 28.408 0 46 16.359 28.408 32.715" style="fill: var(--icon-color)" />
470                           </g>
471                        </svg>
472                     </div>
473                  </div>
474                  <a class="item__link" target="_self" href="https://toppfotball.no/ak25/forord"></a>
475               </div>
476            </div>
477
478         
479
480         
481
482            <div class="item rounded">
483               <div class="item__wrapper">
484                  <figure class="item__image">
485                     <img alt="Image" src="https://toppfotball.no/ak25/_/image/ea84300b-af37-451c-bf17-7b47ff3a8f9d:35d735c2e89c4556ec0ca6a61ca09cbc0f196dd2/block-800-450/1769152907042-48538224-7583-47ce-bc53-d76bc9ba06f5_2.png.jpg">
486                  </figure>
487                  <div class="item__content">
488                     <div class="item__title">
489                        <h2>
490                           <span>Bakgrunn og metode</span>
491                        </h2>
492                     </div>
493                     <div class="item__text">
494                        <span>Bli kjent med bakgrunnen og metodene til Akademiklassifiseringen, og få et historisk tilbakeblikk.</span>
495                     </div>
496                     <div class="item__icon">
497                        <svg xmlns="http://www.w3.org/2000/svg" width="46" height="32.715" viewBox="0 0 46 32.715">
498                           <title>arrow</title>
499                           <g>
500                              <line y1="16.355" x2="41.662" y2="16.355" style="fill: none;stroke: var(--icon-color);stroke-miterlimit: 10;stroke-width: 4px" />
501                              <polygon points="28.408 32.715 25.68 29.785 40.127 16.359 25.68 2.93 28.408 0 46 16.359 28.408 32.715" style="fill: var(--icon-color)" />
502                           </g>
503                        </svg>
504                     </div>
505                  </div>
506                  <a class="item__link" target="_self" href="https://toppfotball.no/ak25/bakgrunn-og-metode"></a>
507               </div>
508            </div>
509
510         
511
512         
513
514            <div class="item rounded">
515               <div class="item__wrapper">
516                  <figure class="item__image">
517                     <img alt="Image" src="https://toppfotball.no/ak25/_/image/706603fe-0e78-4ffe-8d7b-cfe29cc9ce6b:85a01a957c0575ca330a34a5783faba5b762bcce/block-800-450/1769152907042-48538224-7583-47ce-bc53-d76bc9ba06f5_4.png.jpg">
518                  </figure>
519                  <div class="item__content">
520                     <div class="item__title">
521                        <h2>
522                           <span>Rikets tilstand</span>
523                        </h2>
524                     </div>
525                     <div class="item__text">
526                        <span>Rikets tilstand består av elleve kjerneområder. Få full oversikt her.</span>
527                     </div>
528                     <div class="item__icon">
529                        <svg xmlns="http://www.w3.org/2000/svg" width="46" height="32.715" viewBox="0 0 46 32.715">
530                           <title>arrow</title>
531                           <g>
532                              <line y1="16.355" x2="41.662" y2="16.355" style="fill: none;stroke: var(--icon-color);stroke-miterlimit: 10;stroke-width: 4px" />
533                              <polygon points="28.408 32.715 25.68 29.785 40.127 16.359 25.68 2.93 28.408 0 46 16.359 28.408 32.715" style="fill: var(--icon-color)" />
534                           </g>
535                        </svg>
536                     </div>
537                  </div>
538                  <a class="item__link" target="_self" href="https://toppfotball.no/ak25/rikets-tilstand"></a>
539               </div>
540            </div>
541
542         
543
544         
545
546            <div class="item rounded">
547               <div class="item__wrapper">
548                  <figure class="item__image">
549                     <img alt="Image" src="https://toppfotball.no/ak25/_/image/a8f73d03-6d3f-42b9-8f96-6c6c26cd0a26:ac2c93edb48eb38af0645bf2a2d75677bee5a3e6/block-800-450/AK_Forsider_BeggeLigaene_Begge%20ligaene.png.jpg">
550                  </figure>
551                  <div class="item__content">
552                     <div class="item__title">
553                        <h2>
554                           <span>Klubbrapporter</span>
555                        </h2>
556                     </div>
557                     <div class="item__text">
558                        <span>Se rapportene fra alle de 30 klubbene som har blitt vurdert.</span>
559                     </div>
560                     <div class="item__icon">
561                        <svg xmlns="http://www.w3.org/2000/svg" width="46" height="32.715" viewBox="0 0 46 32.715">
562                           <title>arrow</title>
563                           <g>
564                              <line y1="16.355" x2="41.662" y2="16.355" style="fill: none;stroke: var(--icon-color);stroke-miterlimit: 10;stroke-width: 4px" />
565                              <polygon points="28.408 32.715 25.68 29.785 40.127 16.359 25.68 2.93 28.408 0 46 16.359 28.408 32.715" style="fill: var(--icon-color)" />
566                           </g>
567                        </svg>
568                     </div>
569                  </div>
570                  <a class="item__link" target="_self" href="https://toppfotball.no/ak25/klubbene"></a>
571               </div>
572            </div>
573
574         
575
576         
577
578            <div class="item rounded">
579               <div class="item__wrapper">
580                  <figure class="item__image">
581                     <img alt="Image" src="https://toppfotball.no/ak25/_/image/64a87f74-5a95-4fa2-8ba2-4f230b01b22c:a094675f244429c2d05fb4db1c0bf9b101828e68/block-800-450/Tidligere%20rapporter.png.jpg">
582                  </figure>
583                  <div class="item__content">
584                     <div class="item__title">
585                        <h2>
586                           <span>Tidligere rapporter</span>
587                        </h2>
588                     </div>
589                     <div class="item__text">
590                        <span></span>
591                     </div>
592                     <div class="item__icon">
593                        <svg xmlns="http://www.w3.org/2000/svg" width="46" height="32.715" viewBox="0 0 46 32.715">
594                           <title>arrow</title>
595                           <g>
596                              <line y1="16.355" x2="41.662" y2="16.355" style="fill: none;stroke: var(--icon-color);stroke-miterlimit: 10;stroke-width: 4px" />
597                              <polygon points="28.408 32.715 25.68 29.785 40.127 16.359 25.68 2.93 28.408 0 46 16.359 28.408 32.715" style="fill: var(--icon-color)" />
598                           </g>
599                        </svg>
600                     </div>
601                  </div>
602                  <a class="item__link" target="_self" href="https://toppfotball.no/sport/akademiklassifisering"></a>
603               </div>
604            </div>
605
606         
607
608      </div>
609   </div>
610   <!--------------- Alternating view --------------->
611
612   <!--------------- Side by side view -------------->
613   
614   <!--------------- Side by side view -------------->
615</div>
616
617            
618        
619    
620    
621</main>
622
623
624    <div class="navigationBarWrapper">
625	<div class="navigationBar">
626		<div class="navigationBar__items">
627			<div class="navigationBar__items--item">
628				<a class="icon" href="/">
629					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
630						<path d="M14.2495 14.25H9.74945V20.2493L3.75 20.2499V10.5L12 3L20.25 10.5V20.2499L14.2495 20.2493V14.25Z" stroke="white" stroke-width="1.5" stroke-linecap="round"/>
631					</svg>
632				</a>
633			</div>
634			<div class="navigationBar__items--item">
635				<button class="icon" data-itemNav="search">
636					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
637						<path d="M10.875 18.75C15.2242 18.75 18.75 15.2242 18.75 10.875C18.75 6.52576 15.2242 3 10.875 3C6.52576 3 3 6.52576 3 10.875C3 15.2242 6.52576 18.75 10.875 18.75Z" stroke="white" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
638						<path d="M16.4431 16.4438L20.9994 21.0001" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
639					</svg>
640				</button>
641			</div>
642			<div class="navigationBar__items--item">
643				<a class="icon" href="https://fantasy.eliteserien.no/" target="_blank">
644					<img src="/_/image/2ae3929f-9db8-492c-ad3b-12fe0a46d5ec:d3b5fb4e2ce0059858ae8949a2ba48f3d401011f/block-24-24/fantasy-logo_white_responsive.svg" />
645				</a>
646			</div>
647			<div class="navigationBar__items--item" hidden>
648				<button class="icon" data-itemNav="user">
649					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
650						<path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke="white" stroke-width="1.5" stroke-miterlimit="10"/>
651						<path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
652					</svg>
653				</button>
654			</div>
655			<div class="navigationBar__items--item">
656				<button class="icon" data-itemNav="menu">
657					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
658						<path d="M3.75 12H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
659						<path d="M3.75 6H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
660						<path d="M3.75 18H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
661					</svg>
662				</button>
663			</div>
664		</div>
665	</div>
666</div>
667
668<div class="navigationContentWrapper" data-itemNav="search" aria-expanded="false">
669
670	<div class="navigationArea"></div>
671	<div class="navigationBtnSwipe"></div>
672
673	<div class="navigationContent">
674
675		<div class="inputSearch">
676            <form action="https://toppfotball.no/sok" method="get">
677                <input type="text" name="text" id="sok-mobile-input" maxlength="128">
678                
679                <button aria-label="Søk">
680                    <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg" aria-hidden="true">
681                        <path d="M10.875 18.75C15.2242 18.75 18.75 15.2242 18.75 10.875C18.75 6.52576 15.2242 3 10.875 3C6.52576 3 3 6.52576 3 10.875C3 15.2242 6.52576 18.75 10.875 18.75Z" stroke="white" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
682                        <path d="M16.4431 16.4438L20.9994 21.0001" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
683                    </svg>
684                </button>
685            </form>
686        </div>
687
688		<div class="popularSearch">
689			<h3>Populære søk</h3>
690			<div class="popularSearch__list">
691				
692			</div>
693		</div>
694
695	</div>
696</div>
697
698<div class="navigationContentWrapper" data-itemNav="user" aria-expanded="false" data-service-url="/_/service/no.seeds.app.football/get-idrettens-detail
698s">
699
700    <div class="navigationArea"></div>
701	<div class="navigationBtnSwipe"></div>
702
703	<div class="navigationContent">
704		<div class="ui loader"></div>
705		<div class="loginTab loginButton" hidden>
706			<div class="loginTab__header--content">
707				<p id="loginMessage" class="login-description"></p>
708				<a class="modal-open" href="javascript:void(0)"></a>
709			</div>
710		</div>
711        <div class="loginTab userDetails" hidden>
712            <div class="navigationButtons">
713                <a href="https://toppfotball.no/pwa" class="button active">PROFIL</a>
714                
715                <a href="https://toppfotball.no/pwa?edit=true" class="button">REDIGER PROFIL</a>
716             </div>
717            <div class="loginTab__header">
718                <div class="loginTab__header--image">
719					<div class="ntfpwa__default__profile__small"></div>
720                </div>
721                <div class="loginTab__header--content">
722                    <span name="completename"></span>
723                </div>
724				<div class="loginTab__header--notification renew-push-notifications" style="display: none;">
725					<svg stroke="white" width="32px" height="64px" viewBox="0 0 611.999 611.999" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
726						<title id="renewPushTitle"></title>
727						<path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
728							C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
729							c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
730							h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
731							c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
732							C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
733							c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
734							c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
735							M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
736							c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
737							c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"></path>
738						<path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
739							c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
740							C323.259,126.96,315.532,119.235,306.001,119.235z"></path>
741					</svg>
742					<div class="notification-loading">
743						<img src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/img/loading.gif" />
744					</div>
745				</div>
746            </div>
747
748            <div class="loginTab__content">
749                <dl class="loginTab__content--info">
750					<dt>EPost</dt>
751                    <dd name="email"></dd>
752					<dt>Mobilnummer</dt>
753					<dd name="phone"></dd>
754					<dt>Fødselsdato</dt>
755					<dd name="birthdate"></dd>
756					<dt>Adresse</dt>
757					<dd name="address"></dd>
758					<dt>Postnr.</dt>
759					<dd name="zipcode"></dd>
760					<dt>Poststed</dt>
761					<dd name="city"></dd>
762					<dt>Kjønn</dt>
763					<dd name="sex"></dd>
764                </dl>
765
766                <h4>Pushmeldinger</h4>
767
768                <dl class="loginTab__content--options notification-tab">
769                    <dt>Generelle varslinger</dt>
770                    <dd name="general-alert">
771                        <div class="switch__container">
772                            <input id="notification-general-alert-from-bottom" data-id="notification-general-alert" class="switch switch--shadow" type="checkbox" disabled />
773                            <label for="notification-general-alert-from-bottom"></label>
774                        </div>
775                    </dd>
776                    <dt>Varsling ved publisering av nyheter</dt>
777                    <dd name="news">
778                        <div class="switch__container">
779                            <input id="notification-news-from-bottom" data-id="notification-news" class="switch switch--shadow" type="checkbox" disabled />
780                            <label for="notification-news-from-bottom"></label>
781                        </div>
782                    </dd>
783                    <dt>Kamphendelser</dt>
784                    <dd name="match">
785                        <div class="switch__container">
786                            <input id="notification-match-from-bottom" data-id="notification-match" class="switch switch--shadow" type="checkbox" disabled />
787                            <label for="notification-match-from-bottom"></label>
788                        </div>
789                    </dd>
790                </dl>
791
792                <h4>Kommunikasjon og Samtykker</h4>
793
794                <dl class="loginTab__content--options">
795					
796                </dl>
797            </div>
798			<div class="navigationButtons">
799                <a href="" class="button">REDIGER SAMTYKKER</a>
800             </div>
801        </div>
802	</div>
803</div>
804
805<div class="navigationContentWrapper" data-itemNav="menu" aria-expanded="false">
806
807    <div class="navigationArea"></div>
808	<div class="navigationBtnSwipe"></div>
809
810	<div class="navigationContent">
811		
812
813		<div class="groupLink">
814			<a class="item" href="https://toppfotball.no/nyheter">
815                Nyheter
816                
817				
818				
819				
820            </a><a class="item" href="https://toppfotball.no/ak25">
821                Akademiklassifiseringen
822                
823				
824				
825				
826            </a><a class="item" href="https://toppfotball.no/sport">
827                Sport
828                
829				
830				
831				
832            </a><a class="item" href="https://toppfotball.no/eliteserien">
833                Eliteserien
834                
835				
836				
837				
838            </a><a class="item" href="https://toppfotball.no/obos-ligaen">
839                OBOS-ligaen
840                
841				
842				
843				
844            </a><a class="item" href="https://toppfotball.no/partnere">
845                Partnere
846                
847				
848				
849				
850            </a><a class="item" href="https://toppfotball.no/om-oss">
851                Om oss
852                
853				
854				
855				
856            </a><a class="item" href="https://toppfotball.no/sport/nasjonale-serier-ntf-elitetiltak">
857                Nasjonale serier
858                
859				
860				
861				
862            </a>
863		</div>
864
865		<div class="groupLink">
866			
867				<a class="item" href="https://toppfotball.no/tjenestekatalogen">
868					Tjenestekatalogen
869					
870				</a>
871			
872				<a class="item" href="https://toppfotball.no/manualer">
873					Manualer
874					
875				</a>
876			
877		</div>
878
879		<div class="groupLink">
880			<a class="item open-push-notification-modal" href="javascript:void(0)" style="display: none;">
881				PUSH-VARSLINGER
882				<span>
883					<svg stroke="white" width="24px" height="20px" viewBox="0 0 611.999 611.999" fill="#010101" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
884                        <title id="renewPushTitle"></title>
885                        <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
886                            C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
887                            c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
888                            h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
889                            c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
890                            C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
891                            c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
892                            c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
893                            M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
894                            c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
895                            c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"/>
896                        <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
897                            c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
898                            C323.259,126.96,315.532,119.235,306.001,119.235z"/>
899                    </svg>
900				</span>
901			</a>
902		</div>
903	</div>
904
905</div>
906
907
908    <footer class="footer">
909	<div class="footer__bar">
910		<a class="footer__bar__brand" href="/" >
911			<img class="footer__bar__brand__img" src="https://toppfotball.no/ak25/_/image/81feb359-1446-47e1-a9a0-136ea399a33e:96d4bfee1d4878832977533041bb1cef20edd275/wide-72-72/ntf-logo-sidetekst.svg" alt="Klubb"/>
912		</a>
913	</div>
914	<div class="footer__content">
915		<div class="container">
916			<p>
917			<span class="footer__contact">
918				<span>E-post</span>:
919				<a href="/cdn-cgi/l/email-protection#f4849b8780b4809b8484929b8096959898da9a9b"><span class="__cf_email__" data-cfemail="52223d212612263d2222343d2630333e3e7c3c3d">[email&#160;protected]</span></a>
920			</span>
921			
922			
923			
924			</p>
925			<div class="o-space-grid-gutter"></div>
926			<p>
927			<span class="footer__contact">
928				<a target="_blank" class="link link--with-icon" href="https://www.facebook.com/NorskToppfotball">
929					<span class="link__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
930<g>
931	<path d="M12,0C5.3725586,0,0,5.3725586,0,12s5.3725586,12,12,12s12-5.3725586,12-12S18.6274414,0,12,0z M14.5249634,12.3076782
932		h-1.6512451c0,2.6392212,0,5.8892212,0,5.8892212h-2.4484863c0,0,0-3.2174683,0-5.8892212H9.2615356v-2.0810547h1.1636963
933		V8.8809204c0-0.9638672,0.4581909-2.4708252,2.4697266-2.4708252l1.8133545,0.0076294V8.437439c0,0-1.1022949,0-1.3163452,0
934		c-0.2142944,0-0.5182495,0.1066895-0.5182495,0.5664673v1.2227173h1.8647461L14.5249634,12.3076782z"></path>
935</g>
936</svg></span>
937					Facebook
938				</a>
939			</span><span class="footer__contact">
940				<a target="_blank" class="link link--with-icon" href="https://twitter.com/notoppfotball/">
941					<span class="link__icon"><svg version="1.1" id="svg5" xmlns:svg="http://www.w3.org/2000/svg"
942	 xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 1668.56 1221.19"
943	 style="enable-background:new 0 0 1668.56 1221.19;" xml:space="preserve">
944<circle cx="834.28" cy="610.595" r="800" fill="white"/>
945<g id="layer1" transform="translate(52.390088,-25.058597)">
946	<path id="path1009" d="M283.94,167.31l386.39,516.64L281.5,1104h87.51l340.42-367.76L984.48,1104h297.8L874.15,558.3l361.92-390.99
947		h-87.51l-313.51,338.7l-253.31-338.7H283.94z M412.63,231.77h136.81l604.13,807.76h-136.81L412.63,231.77z" fill="black"/>
948</g>
949</svg>
950</span>
951					Twitter
952				</a>
953			</span>
954			</p>
955			<div class="o-space-gutter-3"></div>
956			<form class="newsletter ng-pristine ng-scope ng-valid-email ng-invalid ng-invalid-required" data-ng-controller="newsletter" name="formNewsletter" data-custom-submit="submitForm(input)" novalidate="novalidate">
957				<div data-ng-hide="formNewsletter.formNewsletterEmail.$valid &amp;&amp; !formNewsletter.formNewsletterEmail.$errors &amp;&amp; submitted">
958					<label class="label" for="formNewsletterEmail">Abonner på nyhetsbrev fra Norsk Toppfotball</label>
959					<div class="newsletter__input">
960						<div class="form__block">
961							<input class="input ng-pristine ng-untouched ng-empty ng-valid-email ng-invalid ng-invalid-required" name="formNewsletterEmail" id="formNewsletterEmail" aria-describedby="formNewsletterEmailError" type="email" value="" data-ng-model="input.formNewsletterEmailValidation" required="" placeholder="E-postadresse" />
962							<!-- ngIf: formNewsletter.formNewsletterEmail.$invalid && submitted -->
963						</div>
964					</div>
965					<div class="newsletter__submit">
966						<button class="button button--full" type="submit">PÃ¥melding</button>
967					</div>
968				</div>
969				<div class="newsletter__success ng-hide" data-ng-show="formNewsletter.formNewsletterEmail.$valid &amp;&amp; !formNewsletter.formNewsletterEmail.$errors &amp;&amp; submitted">
970					<div class="box" ng-cloak="">
971						<p ng-bind="newsletterResponse" class="o-color-ntf-safe-dark">
972							Takk for din påmelding!
973						</p>
974					</div>
975				</div>
976			</form>
977			<p><b>Foto</b>:  NTB - <b>Redaktør</b>:  <a href="/cdn-cgi/l/email-protection#4b3f2324262a380b3f243b3b2d243f292a2727652524">Thomas Torjusen</a><br><br><a href="https://toppfotball.no/tjenestekatalogen">Tjenestekatalogen</a></p>
978
979			<p>
980				<a href="https://toppfotball.no/vilkar-og-betingelser" target="_self">Vilkår og betingelser</a>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="https://toppfotball.no/personvern" target="_self">Personvern</a>
981			</p>
982		</div>
983	</div>
984</footer>
985
986
987
988<div class="modal-login">
989    <a href="javascript:void(0)" title="Close" class="modal-login__close">X</a>
990    <div class="modal-login__title">
991        
992    </div>
993    <div class="modal-login__content">
994        
995    </div>
996</div>
997
998<div class="modal-notification">
999    <a href="javascript:void(0)" title="Close" class="modal-notification__close">X</a>
1000    <div class="modal-notification__title">
1001        <h2>Header</h2>
1002    </div>
1003    <div class="modal-notification__content">
1004        <p>Content</p>
1005    </div>
1006</div>
1007
1008<div class="modal-notification-switch">
1009    <a href="javascript:void(0)" title="Close" class="modal-notification-switch__close">X</a>
1010    <div class="modal-notification-switch__title">
1011        <h2>
1012            <svg stroke="#010101" width="24px" height="24px" viewBox="0 0 611.999 611.999" fill="#010101" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
1013                <title id="renewPushTitle"></title>
1014                <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
1015                    C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
1016                    c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
1017                    h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
1018                    c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
1019                    C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
1020                    c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
1021                    c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
1022                    M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
1023                    c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
1024                    c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"></path>
1025                <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
1026                    c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
1027                    C323.259,126.96,315.532,119.235,306.001,119.235z"></path>
1028            </svg>
1029            <span>Header</span>
1030        </h2>
1031    </div>
1032    <div class="modal-notification-switch__content">
1033        <p>Content</p>
1034    </div>
1035    <div class="switch__container">
1036        <input id="modal-notification-switch" class="switch switch--shadow" type="checkbox" />
1037        <label for="modal-notification-switch"></label>
1038        <div class="modal-notification-loading">
1039            <img src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/img/loading.gif" />
1040        </div>
1041    </div>
1042</div>
vendor: 110 bytes, lines 1042-1044
1042
1043
1044<script data-cfasync="false" src="/cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js"></script>
1044<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/compiled/js/app.bundle.js"></script>
vendor: 1 bytes, line 1044
1044
1045<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/js/blazy.js" defer></script>
vendor: 1 bytes, line 1045
1045
1046<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/js/navigation-bar.js"></script>
vendor: 1 bytes, line 1046
1046
1047<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1917e80/js/embed-league-table.js"></script>
1047
1048
1049
1050
1051
1052
1053<script type="text/javascript" src="/_/asset/ntfpwa:0000019dab7c0930/bundles/js/sw/register.js"></script>
vendor: 1 bytes, line 1053
1053
1054<script type="text/javascript">
1055    Starter.registerServiceWorker('https://toppfotball.no/')
1056</script>
1056
1057<!-- Firebase SW -->
1058<script src="https://www.gstatic.com/firebasejs/10.9.0/firebase-app-compat.js"></script>
vendor: 1 bytes, line 1058
1058
1059<script src="https://www.gstatic.com/firebasejs/10.9.0/firebase-messaging-compat.js"></script>
vendor: 1 bytes, line 1059
1059
1060<script type="text/javascript" src="/_/asset/ntfpwa:0000019dab7c0930/bundles/js/push-notification.js" data-service-connect-url="https://toppfotball.no/ak25/_/service/no.seeds.app.football/push-notification-connect" data-service-manage-notifications-url="https://toppfotball.no/ak25/_/service/no.seeds.app.football/push-notification-manage" data-icon-url="/_/service/no.seeds.app.football/asset/0000019ff1917e80/img/logo/ntf/android-icon-512x512.png" data-email-domain="toppfotball.no" data-is-loged="false">
1061</script>
1061
1062<!-- Firebase SW end -->
1063
1064<script>
1065    var isAlreadyLoggedIdrettens = localStorage.getItem('isAlreadyLoggedIdrettens') || false;
1066    if (isAlreadyLoggedIdrettens) {
1067        localStorage.setItem('isAlreadyLoggedIdrettens', true);
1068    }
1069</script>
1069
1070
1071<script>(function(){function c(){var b=a.contentDocument||(a.contentWindow&&a.contentWindow.document);if(b){var d=b.createElement('script');d.innerHTML="window.__CF$cv$params={r:'a443b83fefbc5d07',t:'MTc5MDk0NDI0MA=='};var a=document.createElement('script');a.src='/cdn-cgi/challenge-platform/scripts/jsd/main.js';document.getElementsByTagName('head')[0].appendChild(a);";b.getElementsByTagName('head')[0].appendChild(d)}}if(document.body){var a=document.createElement('iframe');a.height=1;a.width=1;a.style.position='absolute';a.style.top=0;a.style.left=0;a.style.border='none';a.style.visibility='hidden';document.body.appendChild(a);if('loading'!==document.readyState)c();else if(window.addEventListener)document.addEventListener('DOMContentLoaded',c);else{var e=document.onreadystatechange||function(){};document.onreadystatechange=function(b){e(b);'loading'!==document.readyState&&(document.onreadystatechange=e,c())}}}})();</script>
1071<script type="module" src="https://static.cloudflareinsights.com/beacon.min.js/v31edd6df95cf4e85bb4c19e7a9bdbcba1788362987495" integrity="sha512-iIg7k2xntmwu6/uSb5tpc/hySgZc4eoL31yB29W6tJFo2akwjPWcEqnCEdJvGexCL0KEQwVYv5BlowfhVz26hg==" data-cf-beacon='{"version":"2024.11.0","token":"7e3656b10a2643a3b5c6d46183f6a923","r":1,"spa":2}' crossorigin="anonymous"></script>
1071
1072</body>
1073</html>

Line numbers count LF bytes from the start of the resource, as the search results do. Vendor segments are library code the classifier recognised; they are stored but not indexed. Bytes are shown as Latin1 characters, one per byte.